pub struct ProcessingDirective {
    pub event_filter: Option<Box<EventFilter>>,
}
ProcessingDirective : Additional information passed to the subscription to control the processing of notifications. For example, you can use an eventFilter to customize your subscription to send notifications for only the specified marketplaceId’s, or select the aggregation time period at which to send notifications (e.g. limit to one notification every five minutes for high frequency notifications). The specific features available vary depending on the notificationType. This feature is limited to specific notificationTypes and is currently only supported by the ANY_OFFER_CHANGED notificationType.

Fields

event_filter: Option<Box<EventFilter>>

Implementations

Additional information passed to the subscription to control the processing of notifications. For example, you can use an eventFilter to customize your subscription to send notifications for only the specified marketplaceId’s, or select the aggregation time period at which to send notifications (e.g. limit to one notification every five minutes for high frequency notifications). The specific features available vary depending on the notificationType. This feature is limited to specific notificationTypes and is currently only supported by the ANY_OFFER_CHANGED notificationType.